import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
export interface PagesProjectConfig extends cdktf.TerraformMetaArguments {
    /**
    * The account identifier to target for the resource.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#account_id PagesProject#account_id}
    */
    readonly accountId: string;
    /**
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#id PagesProject#id}
    *
    * Please be aware that the id field is automatically added to all resources in Terraform providers using a Terraform provider SDK version below 2.
    * If you experience problems setting this value it might not be settable. Please take a look at the provider documentation to ensure it should be settable.
    */
    readonly id?: string;
    /**
    * Name of the project.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#name PagesProject#name}
    */
    readonly name: string;
    /**
    * The name of the branch that is used for the production environment.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#production_branch PagesProject#production_branch}
    */
    readonly productionBranch: string;
    /**
    * build_config block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#build_config PagesProject#build_config}
    */
    readonly buildConfig?: PagesProjectBuildConfig;
    /**
    * deployment_configs block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#deployment_configs PagesProject#deployment_configs}
    */
    readonly deploymentConfigs?: PagesProjectDeploymentConfigs;
    /**
    * source block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#source PagesProject#source}
    */
    readonly source?: PagesProjectSource;
}
export interface PagesProjectBuildConfig {
    /**
    * Command used to build project.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#build_command PagesProject#build_command}
    */
    readonly buildCommand?: string;
    /**
    * Output directory of the build.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#destination_dir PagesProject#destination_dir}
    */
    readonly destinationDir?: string;
    /**
    * Directory to run the command.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#root_dir PagesProject#root_dir}
    */
    readonly rootDir?: string;
    /**
    * The classifying tag for analytics.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#web_analytics_tag PagesProject#web_analytics_tag}
    */
    readonly webAnalyticsTag?: string;
    /**
    * The auth token for analytics.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#web_analytics_token PagesProject#web_analytics_token}
    */
    readonly webAnalyticsToken?: string;
}
export declare function pagesProjectBuildConfigToTerraform(struct?: PagesProjectBuildConfigOutputReference | PagesProjectBuildConfig): any;
export declare class PagesProjectBuildConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PagesProjectBuildConfig | undefined;
    set internalValue(value: PagesProjectBuildConfig | undefined);
    private _buildCommand?;
    get buildCommand(): string;
    set buildCommand(value: string);
    resetBuildCommand(): void;
    get buildCommandInput(): string | undefined;
    private _destinationDir?;
    get destinationDir(): string;
    set destinationDir(value: string);
    resetDestinationDir(): void;
    get destinationDirInput(): string | undefined;
    private _rootDir?;
    get rootDir(): string;
    set rootDir(value: string);
    resetRootDir(): void;
    get rootDirInput(): string | undefined;
    private _webAnalyticsTag?;
    get webAnalyticsTag(): string;
    set webAnalyticsTag(value: string);
    resetWebAnalyticsTag(): void;
    get webAnalyticsTagInput(): string | undefined;
    private _webAnalyticsToken?;
    get webAnalyticsToken(): string;
    set webAnalyticsToken(value: string);
    resetWebAnalyticsToken(): void;
    get webAnalyticsTokenInput(): string | undefined;
}
export interface PagesProjectDeploymentConfigsPreview {
    /**
    * Compatibility date used for Pages Functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#compatibility_date PagesProject#compatibility_date}
    */
    readonly compatibilityDate?: string;
    /**
    * Compatibility flags used for Pages Functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#compatibility_flags PagesProject#compatibility_flags}
    */
    readonly compatibilityFlags?: string[];
    /**
    * D1 Databases used for Pages Functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#d1_databases PagesProject#d1_databases}
    */
    readonly d1Databases?: {
        [key: string]: string;
    };
    /**
    * Durable Object namespaces used for Pages Functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#durable_object_namespaces PagesProject#durable_object_namespaces}
    */
    readonly durableObjectNamespaces?: {
        [key: string]: string;
    };
    /**
    * Environment variables for Pages Functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#environment_variables PagesProject#environment_variables}
    */
    readonly environmentVariables?: {
        [key: string]: string;
    };
    /**
    * KV namespaces used for Pages Functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#kv_namespaces PagesProject#kv_namespaces}
    */
    readonly kvNamespaces?: {
        [key: string]: string;
    };
    /**
    * R2 Buckets used for Pages Functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#r2_buckets PagesProject#r2_buckets}
    */
    readonly r2Buckets?: {
        [key: string]: string;
    };
}
export declare function pagesProjectDeploymentConfigsPreviewToTerraform(struct?: PagesProjectDeploymentConfigsPreviewOutputReference | PagesProjectDeploymentConfigsPreview): any;
export declare class PagesProjectDeploymentConfigsPreviewOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PagesProjectDeploymentConfigsPreview | undefined;
    set internalValue(value: PagesProjectDeploymentConfigsPreview | undefined);
    private _compatibilityDate?;
    get compatibilityDate(): string;
    set compatibilityDate(value: string);
    resetCompatibilityDate(): void;
    get compatibilityDateInput(): string | undefined;
    private _compatibilityFlags?;
    get compatibilityFlags(): string[];
    set compatibilityFlags(value: string[]);
    resetCompatibilityFlags(): void;
    get compatibilityFlagsInput(): string[] | undefined;
    private _d1Databases?;
    get d1Databases(): {
        [key: string]: string;
    };
    set d1Databases(value: {
        [key: string]: string;
    });
    resetD1Databases(): void;
    get d1DatabasesInput(): {
        [key: string]: string;
    } | undefined;
    private _durableObjectNamespaces?;
    get durableObjectNamespaces(): {
        [key: string]: string;
    };
    set durableObjectNamespaces(value: {
        [key: string]: string;
    });
    resetDurableObjectNamespaces(): void;
    get durableObjectNamespacesInput(): {
        [key: string]: string;
    } | undefined;
    private _environmentVariables?;
    get environmentVariables(): {
        [key: string]: string;
    };
    set environmentVariables(value: {
        [key: string]: string;
    });
    resetEnvironmentVariables(): void;
    get environmentVariablesInput(): {
        [key: string]: string;
    } | undefined;
    private _kvNamespaces?;
    get kvNamespaces(): {
        [key: string]: string;
    };
    set kvNamespaces(value: {
        [key: string]: string;
    });
    resetKvNamespaces(): void;
    get kvNamespacesInput(): {
        [key: string]: string;
    } | undefined;
    private _r2Buckets?;
    get r2Buckets(): {
        [key: string]: string;
    };
    set r2Buckets(value: {
        [key: string]: string;
    });
    resetR2Buckets(): void;
    get r2BucketsInput(): {
        [key: string]: string;
    } | undefined;
}
export interface PagesProjectDeploymentConfigsProduction {
    /**
    * Compatibility date used for Pages Functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#compatibility_date PagesProject#compatibility_date}
    */
    readonly compatibilityDate?: string;
    /**
    * Compatibility flags used for Pages Functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#compatibility_flags PagesProject#compatibility_flags}
    */
    readonly compatibilityFlags?: string[];
    /**
    * D1 Databases used for Pages Functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#d1_databases PagesProject#d1_databases}
    */
    readonly d1Databases?: {
        [key: string]: string;
    };
    /**
    * Durable Object namespaces used for Pages Functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#durable_object_namespaces PagesProject#durable_object_namespaces}
    */
    readonly durableObjectNamespaces?: {
        [key: string]: string;
    };
    /**
    * Environment variables for Pages Functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#environment_variables PagesProject#environment_variables}
    */
    readonly environmentVariables?: {
        [key: string]: string;
    };
    /**
    * KV namespaces used for Pages Functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#kv_namespaces PagesProject#kv_namespaces}
    */
    readonly kvNamespaces?: {
        [key: string]: string;
    };
    /**
    * R2 Buckets used for Pages Functions.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#r2_buckets PagesProject#r2_buckets}
    */
    readonly r2Buckets?: {
        [key: string]: string;
    };
}
export declare function pagesProjectDeploymentConfigsProductionToTerraform(struct?: PagesProjectDeploymentConfigsProductionOutputReference | PagesProjectDeploymentConfigsProduction): any;
export declare class PagesProjectDeploymentConfigsProductionOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PagesProjectDeploymentConfigsProduction | undefined;
    set internalValue(value: PagesProjectDeploymentConfigsProduction | undefined);
    private _compatibilityDate?;
    get compatibilityDate(): string;
    set compatibilityDate(value: string);
    resetCompatibilityDate(): void;
    get compatibilityDateInput(): string | undefined;
    private _compatibilityFlags?;
    get compatibilityFlags(): string[];
    set compatibilityFlags(value: string[]);
    resetCompatibilityFlags(): void;
    get compatibilityFlagsInput(): string[] | undefined;
    private _d1Databases?;
    get d1Databases(): {
        [key: string]: string;
    };
    set d1Databases(value: {
        [key: string]: string;
    });
    resetD1Databases(): void;
    get d1DatabasesInput(): {
        [key: string]: string;
    } | undefined;
    private _durableObjectNamespaces?;
    get durableObjectNamespaces(): {
        [key: string]: string;
    };
    set durableObjectNamespaces(value: {
        [key: string]: string;
    });
    resetDurableObjectNamespaces(): void;
    get durableObjectNamespacesInput(): {
        [key: string]: string;
    } | undefined;
    private _environmentVariables?;
    get environmentVariables(): {
        [key: string]: string;
    };
    set environmentVariables(value: {
        [key: string]: string;
    });
    resetEnvironmentVariables(): void;
    get environmentVariablesInput(): {
        [key: string]: string;
    } | undefined;
    private _kvNamespaces?;
    get kvNamespaces(): {
        [key: string]: string;
    };
    set kvNamespaces(value: {
        [key: string]: string;
    });
    resetKvNamespaces(): void;
    get kvNamespacesInput(): {
        [key: string]: string;
    } | undefined;
    private _r2Buckets?;
    get r2Buckets(): {
        [key: string]: string;
    };
    set r2Buckets(value: {
        [key: string]: string;
    });
    resetR2Buckets(): void;
    get r2BucketsInput(): {
        [key: string]: string;
    } | undefined;
}
export interface PagesProjectDeploymentConfigs {
    /**
    * preview block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#preview PagesProject#preview}
    */
    readonly preview?: PagesProjectDeploymentConfigsPreview;
    /**
    * production block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#production PagesProject#production}
    */
    readonly production?: PagesProjectDeploymentConfigsProduction;
}
export declare function pagesProjectDeploymentConfigsToTerraform(struct?: PagesProjectDeploymentConfigsOutputReference | PagesProjectDeploymentConfigs): any;
export declare class PagesProjectDeploymentConfigsOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PagesProjectDeploymentConfigs | undefined;
    set internalValue(value: PagesProjectDeploymentConfigs | undefined);
    private _preview;
    get preview(): PagesProjectDeploymentConfigsPreviewOutputReference;
    putPreview(value: PagesProjectDeploymentConfigsPreview): void;
    resetPreview(): void;
    get previewInput(): PagesProjectDeploymentConfigsPreview | undefined;
    private _production;
    get production(): PagesProjectDeploymentConfigsProductionOutputReference;
    putProduction(value: PagesProjectDeploymentConfigsProduction): void;
    resetProduction(): void;
    get productionInput(): PagesProjectDeploymentConfigsProduction | undefined;
}
export interface PagesProjectSourceConfig {
    /**
    * Toggle deployments on this repo. Defaults to `true`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#deployments_enabled PagesProject#deployments_enabled}
    */
    readonly deploymentsEnabled?: boolean | cdktf.IResolvable;
    /**
    * Project owner username.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#owner PagesProject#owner}
    */
    readonly owner?: string;
    /**
    * Enable Pages to comment on Pull Requests. Defaults to `true`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#pr_comments_enabled PagesProject#pr_comments_enabled}
    */
    readonly prCommentsEnabled?: boolean | cdktf.IResolvable;
    /**
    * Branches will be excluded from automatic deployment.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#preview_branch_excludes PagesProject#preview_branch_excludes}
    */
    readonly previewBranchExcludes?: string[];
    /**
    * Branches will be included for automatic deployment.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#preview_branch_includes PagesProject#preview_branch_includes}
    */
    readonly previewBranchIncludes?: string[];
    /**
    * Preview Deployment Setting. Defaults to `all`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#preview_deployment_setting PagesProject#preview_deployment_setting}
    */
    readonly previewDeploymentSetting?: string;
    /**
    * Project production branch name.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#production_branch PagesProject#production_branch}
    */
    readonly productionBranch: string;
    /**
    * Enable production deployments. Defaults to `true`.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#production_deployment_enabled PagesProject#production_deployment_enabled}
    */
    readonly productionDeploymentEnabled?: boolean | cdktf.IResolvable;
    /**
    * Project repository name.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#repo_name PagesProject#repo_name}
    */
    readonly repoName?: string;
}
export declare function pagesProjectSourceConfigToTerraform(struct?: PagesProjectSourceConfigOutputReference | PagesProjectSourceConfig): any;
export declare class PagesProjectSourceConfigOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PagesProjectSourceConfig | undefined;
    set internalValue(value: PagesProjectSourceConfig | undefined);
    private _deploymentsEnabled?;
    get deploymentsEnabled(): boolean | cdktf.IResolvable;
    set deploymentsEnabled(value: boolean | cdktf.IResolvable);
    resetDeploymentsEnabled(): void;
    get deploymentsEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _owner?;
    get owner(): string;
    set owner(value: string);
    resetOwner(): void;
    get ownerInput(): string | undefined;
    private _prCommentsEnabled?;
    get prCommentsEnabled(): boolean | cdktf.IResolvable;
    set prCommentsEnabled(value: boolean | cdktf.IResolvable);
    resetPrCommentsEnabled(): void;
    get prCommentsEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _previewBranchExcludes?;
    get previewBranchExcludes(): string[];
    set previewBranchExcludes(value: string[]);
    resetPreviewBranchExcludes(): void;
    get previewBranchExcludesInput(): string[] | undefined;
    private _previewBranchIncludes?;
    get previewBranchIncludes(): string[];
    set previewBranchIncludes(value: string[]);
    resetPreviewBranchIncludes(): void;
    get previewBranchIncludesInput(): string[] | undefined;
    private _previewDeploymentSetting?;
    get previewDeploymentSetting(): string;
    set previewDeploymentSetting(value: string);
    resetPreviewDeploymentSetting(): void;
    get previewDeploymentSettingInput(): string | undefined;
    private _productionBranch?;
    get productionBranch(): string;
    set productionBranch(value: string);
    get productionBranchInput(): string | undefined;
    private _productionDeploymentEnabled?;
    get productionDeploymentEnabled(): boolean | cdktf.IResolvable;
    set productionDeploymentEnabled(value: boolean | cdktf.IResolvable);
    resetProductionDeploymentEnabled(): void;
    get productionDeploymentEnabledInput(): boolean | cdktf.IResolvable | undefined;
    private _repoName?;
    get repoName(): string;
    set repoName(value: string);
    resetRepoName(): void;
    get repoNameInput(): string | undefined;
}
export interface PagesProjectSource {
    /**
    * Project host type.
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#type PagesProject#type}
    */
    readonly type?: string;
    /**
    * config block
    *
    * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project#config PagesProject#config}
    */
    readonly config?: PagesProjectSourceConfig;
}
export declare function pagesProjectSourceToTerraform(struct?: PagesProjectSourceOutputReference | PagesProjectSource): any;
export declare class PagesProjectSourceOutputReference extends cdktf.ComplexObject {
    private isEmptyObject;
    /**
    * @param terraformResource The parent resource
    * @param terraformAttribute The attribute on the parent resource this class is referencing
    */
    constructor(terraformResource: cdktf.IInterpolatingParent, terraformAttribute: string);
    get internalValue(): PagesProjectSource | undefined;
    set internalValue(value: PagesProjectSource | undefined);
    private _type?;
    get type(): string;
    set type(value: string);
    resetType(): void;
    get typeInput(): string | undefined;
    private _config;
    get config(): PagesProjectSourceConfigOutputReference;
    putConfig(value: PagesProjectSourceConfig): void;
    resetConfig(): void;
    get configInput(): PagesProjectSourceConfig | undefined;
}
/**
* Represents a {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project cloudflare_pages_project}
*/
export declare class PagesProject extends cdktf.TerraformResource {
    static readonly tfResourceType = "cloudflare_pages_project";
    /**
    * Create a new {@link https://www.terraform.io/docs/providers/cloudflare/r/pages_project cloudflare_pages_project} Resource
    *
    * @param scope The scope in which to define this construct
    * @param id The scoped construct ID. Must be unique amongst siblings in the same scope
    * @param options PagesProjectConfig
    */
    constructor(scope: Construct, id: string, config: PagesProjectConfig);
    private _accountId?;
    get accountId(): string;
    set accountId(value: string);
    get accountIdInput(): string | undefined;
    get createdOn(): string;
    get domains(): string[];
    private _id?;
    get id(): string;
    set id(value: string);
    resetId(): void;
    get idInput(): string | undefined;
    private _name?;
    get name(): string;
    set name(value: string);
    get nameInput(): string | undefined;
    private _productionBranch?;
    get productionBranch(): string;
    set productionBranch(value: string);
    get productionBranchInput(): string | undefined;
    get subdomain(): string;
    private _buildConfig;
    get buildConfig(): PagesProjectBuildConfigOutputReference;
    putBuildConfig(value: PagesProjectBuildConfig): void;
    resetBuildConfig(): void;
    get buildConfigInput(): PagesProjectBuildConfig | undefined;
    private _deploymentConfigs;
    get deploymentConfigs(): PagesProjectDeploymentConfigsOutputReference;
    putDeploymentConfigs(value: PagesProjectDeploymentConfigs): void;
    resetDeploymentConfigs(): void;
    get deploymentConfigsInput(): PagesProjectDeploymentConfigs | undefined;
    private _source;
    get source(): PagesProjectSourceOutputReference;
    putSource(value: PagesProjectSource): void;
    resetSource(): void;
    get sourceInput(): PagesProjectSource | undefined;
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
